import bb.cascades 1.3
import bb.data 1.0
import org.labsquare 1.0
import org.Hill 1.0
import bb.device 1.3

Page {
    id: page
    property string account
    property string channel
    property string channelId
    property bool following
    property string token
    signal urlChanged

    actionBarVisibility: ChromeVisibility.Visible
    
    titleBar: TitleBar {
        kind: TitleBarKind.FreeForm
        kindProperties: FreeFormTitleBarKindProperties {
            Titlebar {
                id: titleBar
                titleText: "Account"
            }
        }
        visibility: ChromeVisibility.Visible
    
    }
    Container {
        SegmentedControl {
            id: searchOptions
            
            Option {
                id: info
                text: "About"
                selected: true
            }
            
            Option {
                id: chatOption
                text: "Chat"
            }
            
            onSelectedOptionChanged: {
                //queryData.clear()
                if(selectedOption == info){
                    chat.visible             = false
                    profilePage.visible       = true
                
                }else{
                    if(chat.getLoggedIn()){chat.visible             = true}
                    
                    profilePage.visible       = false
                }
            
            }
        }
        
        IrcChat {
            id: chat
            visible: false
        }
        
        Profile {
            id: profilePage
        }
        
        RequestM {
            id: proReq
        }
        
        RequestM {
            id: channelReq
        }
        RequestM {
            id: isFollowing
            authenticator: o1
        }
        
        RequestM {
            id: profileReq
        }
        
        attachedObjects: [
            Login {
                id: loginPage
            }
        ]
        layout: StackLayout {
        
        }
    }
    
    //Signal Handelers
    onUrlChanged: {
        console.log("profil url changed:  "+profilePage.profileUrl)
        proReq.url = profilePage.profileUrl
        proReq.sendUserReq()
    }
    
    attachedObjects: [
        GroupDataModel {
            id: profileDataModel
            sortedAscending: false
            grouping: ItemGrouping.None
            function addProfileInfo(d){ 
                console.log("addProfileInfo Called")  
                if(d["name"] != null){
                    titleBar.titleText = d["name"]
                    chat.setChannel(d["name"])
                    channel = d["name"]
                    channelId = d["_id"]
                    account = o1.extraTokens._id;

                    var isFollowingUrl = "https://api.twitch.tv/kraken/users/" + account + "/follows/channels/" + channelId
                    isFollowing.url = isFollowingUrl
                    isFollowing.sendUserReq()
                }
                console.log(d["logo"])
                if(d["logo"] != null){profilePage.imageUrl = d["logo"]}
                //profileImage.setUrl(d["logo"])
                if(d["bio"] != null){profilePage.textBio = d["bio"]}
                channelReq.url = "https://api.twitch.tv/kraken/channels/"+d["_id"]
                channelReq.sendChannelsReq()

            }
        },
        
        GroupDataModel {
            id: channelDataModel
            sortedAscending: false
            grouping: ItemGrouping.None
            
            function addChannelInfo(d){
                profilePage.backgroundUrl = d["profile_banner"]
            }
        }    
    ]//end page attached objects
    
    onCreationCompleted: {
        token = o1.token
        mainAction.setEnabled(false)
        //if user is not logged in, disable main button.
        proReq.userAvailable.connect(profileDataModel.addProfileInfo)
        channelReq.channelsAvailable.connect(channelDataModel.addChannelInfo)
        if(!o1.linked){
            mainAction.setEnabled(false)

        }else{
            isFollowing.userAvailable.connect(page.isFollowing)
        }
        
        
        
    }
    function setUrl(u){
        profilePage.profileUrl = u
        urlChanged()
    }
    
    function isFollowing(d){
        var data = d
        //String means request wasn't parsed in json due to http 404
        if(d.created_at == null){
            console.log("User not followed")
            following = false
            //mainAction.title = "Follow"
        }
        else{
            following = true
            console.log("User followed")
            //mainAction.title = "unFollow"
            
        }
        updateAction()
    }
    
    function follow(){
        var thisUrl = "https://api.twitch.tv/kraken/users/"+account+"/follows/channels/"+channelId
        isFollowing.url = thisUrl
        isFollowing.sendNewPut()
        following = true
        updateAction()
    }
    
    function unFollow(){
        var thisurl = "https://api.twitch.tv/kraken/users/"+account+"/follows/channels/"+channelId
        isFollowing.url = thisurl
        isFollowing.sendNewDelete()
        following = false
        updateAction()
    }
    
    function setProfileName(d){
        account = d.name;
        console.log("setting profile name to: "  + account)
        console.log("Channel testing against is: "+channel)
        var isFollowingUrl = "https://api.twitch.tv/kraken/users/"+o1.extraTokens._id+"/follows/channels/"+channelId
        isFollowing.url = isFollowingUrl
        isFollowing.sendUserReq()
    }
    
    function updateAction(){
        
        if(following){
            mainAction.title = "Unfollow"
            mainAction.imageSource = "asset:///images/Action_Icons/ic_cancel.png"
        }
        else{
            mainAction.title = "Follow"
            mainAction.imageSource = "asset:///images/Action_Icons/ic_add.png"
        }
        mainAction.setEnabled(true)
    }
    
    actions: [
        ActionItem {

            id: mainAction
            title: ""
            ActionBar.placement: ActionBarPlacement.OnBar
            imageSource: "asset:///images/ic_action_logout.png"
            onTriggered: {
                if(following){
                    unFollow()
                }
                else{
                    follow()
                }
                
            }
        }
    ] 

} 