import bb.cascades 1.3

Sheet {
    id: sheet
    Page {
        titleBar: TitleBar {
            title: "Settings"
        }
        id: settings
        property variant theme: Application.themeSupport.theme
        
        //Colours
        property string red: "CC0000"
        property string darkred: "8F0000"
        property string purple: "6441A5" //dark twitch purple
        property string otherpurple: "B9A3E3" //light twitch purple
        property string green: "339933"
        property string darkgreen: "0A1F0A"
        property string blue: "0066CC"
        property string darkblue: "002952"
        property string yellow: "FFFF00"
        property string darkyellow: "999900"
        
       ScrollView {
           id:scroll
            Container {
                Container {      
                    layout: StackLayout {}
                    leftPadding: ui.du(1.5)
                    rightPadding: ui.du(1.5)
                    topPadding: ui.du(1.5)
                    
                    Label {
                        id:colorPickLable
                        text: "Color Scheme"
                        textStyle.fontSize: FontSize.Large
                    }
                    TextArea {
                        id: colorDesc
                        text: "Blink now supports a variety of different colour schemes"
                        +" to customize the look and feel of the app."
                        editable: false
    
                    }
                    Container {
                        DropDown {
                            id: primaryDropDown
                            title: "Primary Color"
                            
                            Option { text: "Purple"; value: settings.purple; }
                            Option { text: "Red"; value: settings.red}
                            Option { text: "Green"; value: settings.green }
                            Option { text: "Blue"; value: settings.blue }
                            
                            onSelectedValueChanged: {
                                var secondary
                                appSettings.setPrimaryColour(primaryDropDown.selectedValue)
                                
                                switch (primaryDropDown.selectedValue){
                                    case settings.purple:
                                        secondary = settings.otherpurple
                                        break;
                                    case settings.red:
                                        secondary = settings.darkred
                                        break;
                                    case settings.green:
                                        secondary = settings.darkgreen
                                        break;
                                    case settings.blue:
                                        secondary = settings.darkblue
                                        break;
                                    default: 
                                        secondary = settings.otherpurple
                                }
                                appSettings.setPrimaryBase(secondary)     
                                setColours(primaryDropDown.selectedValue, secondary)
                            }
                        }
                    }
                }

                Divider {

                }
                Container {
                
                    layout: StackLayout {}
                    leftPadding: ui.du(1.5)
                    rightPadding: ui.du(1.5)
                    topPadding: ui.du(1.5)
                      
                    Label {
                            id: visualStyleLable
                            text: "Visual Style"
                            textStyle.fontSize: FontSize.Large
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.LeftToRight

                        }

                        TextArea {
                            id: visDesc
                            text: "Switch between bright and dark visual styles."
                            editable: false
                            
                        }
                        Button {
                            text: "Switch Theme"
                            onClicked: {
                                if(settings.theme.colorTheme.style == VisualStyle.Dark){
                                    Application.themeSupport.setVisualStyle(VisualStyle.Bright)
                                    appSettings.setVisualTheme("bright")
                                }else{
                                    Application.themeSupport.setVisualStyle(VisualStyle.Dark)
                                    appSettings.setVisualTheme("dark")
                                }
                            }
                                verticalAlignment: VerticalAlignment.Center
                            horizontalAlignment: HorizontalAlignment.Center
                        }
                }
            }
                
//            Divider {
//            
//            }
//            
//            Container {
//                
//                layout: StackLayout {}
//                leftPadding: ui.du(1.5)
//                rightPadding: ui.du(1.5)
//                topPadding: ui.du(1.5)
//                
//                Label {
//                    id: streamModeLable
//                    text: "Stream Mode"
//                    textStyle.fontSize: FontSize.Large
//                }
//                TextArea {
//                    id: streamModeDesc
//                    text: "The HTML5 player is provided by Twitch and was the original video playback mode used by Blink."
//                    +" It provides automatic video quality selection, as well as a variety of full screen features."
//                    +" It is however in beta, and is not guaranteed to work correctly."
//                    editable: false
//                
//                }
//                Container {
//                    horizontalAlignment: HorizontalAlignment.Fill
//                    layout: DockLayout {
//
//                        }
//                    
//                    Label {
//                        text: "Toggle HTML Player:"
//                            horizontalAlignment: HorizontalAlignment.Left
//                    }
//                    
//                    ToggleButton {
//                        id: playerToggle
//                        onCheckedChanged: {
//                            if(checked){
//                                appSettings.setPlayer("stream.qml")
//                            }else{
//                                appSettings.setPlayer("streamv2.qml")
//                            }
//                        }
//                        horizontalAlignment: HorizontalAlignment.Right
//                    }
//                    
//                }
//            }
           
        }//end root container
    }//end scroll
        
    actions: [
        ActionItem {
            title: "Close"
            ActionBar.placement: ActionBarPlacement.Signature
            imageSource: "asset:///images/Action_Icons/ic_clear.png"
            onTriggered: {
                sheet.close()
            }
        }
    ]
    onCreationCompleted: {
        if(appSettings.getPlayer()=="streamv2.qml"){
            playerToggle.setChecked(false)
            console.log("player set to streamv2.qml")
        }else{
            playerToggle.setChecked(true)
        }
    }
    }
    function setColours(primstring, basestring){
        var prim = Color.create("#"+primstring)
        var base = Color.create("#"+basestring)
        Application.themeSupport.setPrimaryColor(prim, base)
        Relay.notifyColourChange()
    }
}