import bb.cascades 1.3
import bb.data 1.0
import org.labsquare 1.0
import org.Hill 1.0
import bb.device 1.3


NavigationPane {
    id:root
    Page {
        property string baseUrl : "https://api.twitch.tv/kraken/search/"
        property string searchUrl
        property string gamesNext
        property string channelsNext
        property string streamsNext
        property string name
        property string token
        
        id: searchPage
        
        titleBar: TitleBar {
            id: titleBar
            title: "Search"
            kind: TitleBarKind.FreeForm
            kindProperties: FreeFormTitleBarKindProperties {
                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    Container {
                        id: logoContainer
                        background: Color.create("#"+appSettings.getPrimaryColour())
                        ImageButton {
                            defaultImageSource: "asset:///images/Blink_shortcut.png"
                            preferredHeight: ui.du(12)
                            preferredWidth: ui.du(12)
                            onClicked: {
                                console.log("Button pressed")
                                Relay.notifyTabbedPane()
                                HighlightAppearance.Full
                            }
                            verticalAlignment: VerticalAlignment.Center
                        }
                    }

                    Label {
                        id: titleLabel
                        text: "Search"
                        textFormat: TextFormat.Plain
                        textStyle.fontSize: FontSize.Large
                        textStyle.textAlign: TextAlign.Left
    
                        verticalAlignment: VerticalAlignment.Center
                        textStyle.fontWeight: FontWeight.Bold
    
                        margin.leftOffset: ui.du(2)
                        textStyle {
                            fontStyle: FontStyle.Normal
                        }
                    }
                    TextField {
                        //text: "Enter Search Query"
                        inputMode: inputMode.Text
                        hintText: "Enter Search query"
                        input {
                            submitKey: SubmitKey.Search
                            onSubmitted: {
                                searchPage.submitQuery()
                                setFocusHighlightEnabled(focusHighlightEnabled)
                            }
                        }
                        id: searchField
                        verticalAlignment: VerticalAlignment.Center
                        horizontalAlignment: HorizontalAlignment.Right
                        margin.rightOffset: ui.du(0)
                        opacity: 0.3
                        textStyle.textAlign: TextAlign.Right
                        
                        onTextChanging: {
                            //if(text != "") searchPage.submitQuery()
                            console.log("SEARCH CHANGING")
                        }
                    }

                }
            }
            branded: TriBool.True
        }
        Container {
            SegmentedControl {
                id: searchOptions
                selectedIndex: 1
    
                Option {
                    id: games
                    text: "Games"
                    value: "games?q="
                    selected: true
                }
    
                Option {
                    id: channels
                    text: "Channels"
                    value: "streams?q="
                }

                Option {
                    id: people
                    text: "People"
                    value: "channels?q="
                }

                onSelectedOptionChanged: {
                    //queryData.clear()
                    searchPage.updateSelectedOption()
                    console.log("Search url: " + searchPage.searchUrl)
                    searchPage.updateVisibility()
                }
            }
            //Games List View
            ListView {
                visible: false
                layout: GridListLayout {
                    columnCount: 3
                    orientation: LayoutOrientation.TopToBottom
                    horizontalCellSpacing: ui.du(1.5)
                    verticalCellSpacing: ui.du(1.5)
                    cellAspectRatio: 0.72
                }
                id: gameslistView
                dataModel: queryData
                leftPadding: ui.du(1.5)
                rightPadding: ui.du(1.5)
                listItemComponents: [
                    ListItemComponent {
                        id: item
                        type: "item"
                        CustomListItem {
                            highlightAppearance: HighlightAppearance.Full
                            dividerVisible: false
                            Game {
                                //preferredWidth: ui.du(40)
                                //preferredHeight: ui.du(55.6)
                                text: ListItemData.name
                                image: ListItemData.box.large
                            }
                        }
                    }     
                ]
                onTriggered: {
                    var i = queryData.data(indexPath)
                    //console.log(i.name)
                    //req.url = "https://api.twitch.tv/kraken/search/streams?q="+i.name
                    var page = channelsDefinition.createObject(); //default channel urls are called
                    page.setURL("https://api.twitch.tv/kraken/streams?game="+i.name)
                    page.getStreams() // clears data and gets new data from set url
                    root.push(page);
                }
            
            }//end of games list view
            
            /*Channels List View*/
            ListView {
                visible: false
                leftPadding: ui.du(1.5)
                rightPadding: ui.du(1.5)
                layout:  GridListLayout {
                    orientation: LayoutOrientation.TopToBottom
                    columnCount: 1
                    cellAspectRatio: 1.8
                    verticalCellSpacing: ui.du(1.5)
                    horizontalCellSpacing: ui.du(1.5)
                }
                
                id: channelsListView
                dataModel: channelsDataModel
                horizontalAlignment: HorizontalAlignment.Center
                listItemComponents: [
                    ListItemComponent {
                        id: channelItem
                        type: "item"
                        CustomListItem {
                            highlightAppearance: HighlightAppearance.Full
                            dividerVisible: false
                            Channel {
                                secondary: ListItemData.game + ":  "+ ListItemData.viewers + " viewers"
                                channel: ListItemData.channel.display_name
                                image: ListItemData.preview.large
                            }
                        }
                    }          
                ]
                //Action to push channels on stack
                onTriggered: {
                    HighlightAppearance.Full
                    var i = dataModel.data(indexPath)
                    channelsReq.url = 'http://api.twitch.tv/api/channels/'+i.channel.name+'/access_token'
                    var page
                    if(appSettings.getPlayer() == "streamv2.qml"){
                        page = streamsDef.createObject();
                    }else{
                        page = htmlstreamsDef.createObject()
                    }
                    
                    page.setURL(i.channel.name)
                    root.push(page)
                }
                
                attachedObjects: [
                    ListScrollStateHandler {
                        onAtEndChanged: {
                            if(atEnd && searchPage.channelsNext != "null"){
                                //console.log("At end of list...")
                                //console.log("Next Link is:  " + channelsNav.channelsNext)
                                channelsReq.url = searchPage.streamsNext
                                channelsReq.sendChannelsReq()
                            }
                        }
                    }
                ]
            
            }//end of list view
            /*Channels List View*/
            
            ListView {
                leftPadding: ui.du(1.5)
                rightPadding: ui.du(1.5)
                layout:  GridListLayout {
                    orientation: LayoutOrientation.TopToBottom
                    columnCount: 1
                    cellAspectRatio: 5.5
                    verticalCellSpacing: ui.du(1.5)
                }
                visible: false
                id: peopleListView
                dataModel: peopleDataModel
                horizontalAlignment: HorizontalAlignment.Center
                listItemComponents: [
                    ListItemComponent {
                        id: peopleItem
                        type: "item"
                        CustomListItem {
                            highlightAppearance: HighlightAppearance.Full
                            User {
                                id: standardListUser
                                name: ListItemData.name
                                status: "Views:  " + ListItemData.views
                                image: ListItemData.logo
                                description: ListItemData.status
                            }
                        }
                    }          
                ]
                //Action to push channels on stack
                onTriggered: {
                    var i = dataModel.data(indexPath)
                    var page = profileDef.createObject();
                    page.setUrl("https://api.twitch.tv/kraken/users/"+i._id)
                    page.account = searchPage.name
                    page.channel = i.name
                    root.push(page)
                }
                
                attachedObjects: [
                    ListScrollStateHandler {
                        onAtEndChanged: {
                            if(atEnd && searchPage.channelsNext != "null"){
                                //console.log("At end of list...")
                                //console.log("Next Link is:  " + channelsNav.channelsNext)
                                channelsReq.url = searchPage.streamsNext
                                channelsReq.sendChannelsReq()
                            }
                        }
                    }
                ]
            
            }//end of list view
            
            Container {
                visible: true
                id: searchResultLable
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
                Label {
                    text: "Nothing to Show..."
                    textStyle.fontSize: FontSize.Large
                    verticalAlignment: VerticalAlignment.Top
                    horizontalAlignment: HorizontalAlignment.Center
                }
                Label {
                    text: "Try a different query"
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Top
                }
            }
            
            onCreationCompleted: {
                OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.DisplayPortrait
                searchPage.token = appSettings.getValueFor("AccessToken")
                searchPage.updateSelectedOption()
                //hide other lists
                channelsListView.visible = false
                console.log(searchPage.searchUrl)
                //connect signals and slots
                userReq.userAvailable.connect(searchPage.setName)
                gamesReq.gamesAvailable.connect(queryData.addTopGames)
                channelsReq.channelsAvailable.connect(channelsDataModel.addStreams)
                peopleReq.channelsAvailable.connect(peopleDataModel.addPeople)
                
                userReq.url = "https://api.twitch.tv/kraken/user/"+"?oauth_token="+searchPage.token
                userReq.sendUserReq()
                
                Relay.colourChange.connect(searchPage.updateColour)
            }
            
            RequestM {
                id: gamesReq
            }
            
            RequestM {
                id: channelsReq
            }
            
            RequestM {
                id: peopleReq
            }
            RequestM {
                id: userReq
            }
            
        }
        function updateColour(){
            var colour = appSettings.getPrimaryColour()
            console.log("Setting title bar colour to:  " + colour)
            logoContainer.background = Color.create("#"+colour)
        }
        
        function setName(d){
            searchPage.name = d.name
        }
        
        function submitQuery(){
            /*Clear data models of previous query*/
            channelsDataModel.clear()
            peopleDataModel.clear()
            searchPage.updateSelectedOption()
            /*Only search for live games?*/
            gamesReq.url = searchPage.baseUrl+"games?query="+searchField.text +"&type=suggest" + "&live=true"
            channelsReq.url = searchPage.baseUrl+"streams?query="+searchField.text
            peopleReq.url = searchPage.baseUrl+"channels?query="+searchField.text
            gamesReq.sendGamesReq()
            channelsReq.sendChannelsReq()
            peopleReq.sendChannelsReq()
            peopleDataModel.clear()
            channelsDataModel.clear()
        }
        
        function updateSelectedOption(){
            searchUrl = baseUrl+searchOptions.selectedOption.value+searchField.text+"&type=suggest"
        }
        
        function updateVisibility(){
            if(searchOptions.selectedOption == channels){
                if(channelsDataModel.isEmpty()){
                    searchResultLable.visible = true
                }else{
                    channelsListView.visible  = true
                    searchResultLable.visible = false
                }
                peopleListView.visible    = false
                gameslistView.visible     = false
            }
            if(searchOptions.selectedOption == games){
                if(queryData.isEmpty()){
                    searchResultLable.visible = true
                }else{
                    gameslistView.visible    = true
                    searchResultLable.visible = false
                }
                channelsListView.visible = false
                peopleListView.visible   = false
            }
            if(searchOptions.selectedOption == people){
                if(peopleDataModel.isEmpty()){
                    searchResultLable.visible = true 
                }else{
                    peopleListView.visible    = true
                    searchResultLable.visible = false
                }
                gameslistView.visible     = false
                channelsListView.visible  = false
            }
        }
        
        
        attachedObjects: [
            GroupDataModel {
                id: queryData
                sortedAscending: false
                grouping: ItemGrouping.None
                sortingKeys: ["popularity"]
                
                function addTopGames(d){
                    queryData.clear()
                    console.log("Add top games called")
                    console.log("first name is:  " + d["games"][0].name)
                    var data = d;
                    if(data["games"] != null){
                        queryData.insertList(data["games"])
                        //searchPage.gamesNext = data["_links"].next
                        searchResultLable.visible = false
                    }
                    searchPage.updateVisibility()
                }
                
            }, // End Games Data Model
            
            /*Channels Data Model*/
            GroupDataModel {
                id: channelsDataModel
                sortedAscending: false
                grouping: ItemGrouping.None
                sortingKeys: ["viewers"]
                
                function addStreams(d){
                    console.log("add streams function called")
                    var data = d
                    if(data["streams"] != null){
                        console.log("data[\"streams\"] is not null...")
                        channelsDataModel.insertList(data["streams"])
//                        searchPage.streamsNext = data["_links"].next
                        searchResultLable.visible = false
                    }
                    searchPage.updateVisibility()
                    //console.log(data.streams[0].preview.toString())
                }
            },
            GroupDataModel {
                id: peopleDataModel
                sortedAscending: false
                grouping: ItemGrouping.None
                sortingKeys: ["views"]
                
                function addPeople(d){
                    var data = d
                    if(data["channels"] != null){
                        console.log("data[\"streams\"] is not null...")
                        peopleDataModel.insertList(data["channels"])
//                        searchPage.channelsNext = data["_links"].next

                        searchResultLable.visible = false
                    }
                    searchPage.updateVisibility()
                    //console.log(data.streams[0].preview.toString())
                }
                
            },
            
            ComponentDefinition {
                id: channelsDefinition
                source: "ChannelsPage.qml"
            },
            ComponentDefinition {
                    id: streamsDef
                    source: "streamv2.qml"
            },
            ComponentDefinition {
                id: htmlstreamsDef
                source: "stream.qml"
            },
            
            ComponentDefinition {
                id: profileDef
                source: "OtherProfile.qml"
            }
            
        ]
    
    }
    onPopTransitionEnded: {
        /*
        if(OrientationSupport.supportedDisplayOrientation != SupportedDisplayOrientation.DisplayPortrait){
            OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.DisplayPortrait
        }*/ 
        page.destroy(); 
    }
}